# Digital 3G - Backend/API

This project provides a HTTP backend and tooling for running the digital 3G verification apps.

## Getting started

This project runs with Python 3. The specific version used in development is 3.9.6 but other >=3.7 versions should be expected to work.

### Using MySQL
To use MySQL instead of SQlite replace `SQLALCHEMY_DATABASE_URI` in `app.py` with your MySQL URI in the form of `mysql://username:password@server/db`

### Generating initial files
To generate the keys and database entries needed for continuing, run `python3 setup.py` and copy the output for configuring the apps later on. The dependencies described below are required for running the setup.

### Development
To get started (in your virtual environment) run `pip3 install -r requirements.txt` to get all required dependencies.
Afterwards, a pair of keys can be generated into the output folder by running `python3 generate_keys.py`. 

For enabling insecure HTTP transport during development, enter `export AUTHLIB_INSECURE_TRANSPORT=1` in your active shell.

Afterwards the Flask server can be started by running `flask run`.

### Production
For the production environment, we are using a Debian 11 server.

To get started with Python and the required plugins run the following (as root)

```bash
apt install python3 python3-flask python3-flask-cors python3-flask-sqlalchemy python3-authlib python3-pycryptodome python3-dateutil python3-sqlalchemy python3-sqlalchemy-util
```

For the production environment it is also strongly recommended to use a WSGI server. In this example we will be using gunicorn:

```bash
apt intall gunicorn3
```

At this point the server can be tested by running

```bash
gunicorn --bind 0.0.0.0:5000 wsgi:app
```

To run the API in the background, a systemd service file is supplied in this project to make setting up easier.
Copy that file or its contents to `/etc/systemd/system/digital_3g.service` and change the paths/uer settings to match those present on your server.

Now enable and run the server by executing 

```systemctl enable digital_3g.service && systemctl start digital_3g.service```

Finally, a nginx proxy can be set up to handle incoming requests and redirecting them to the UNIX socket we created earlier by running the backend service.

To install and enable nginx simply run

```bash
apt install nginx
systemctl enable nginx.service
systemctl start nginx.service
```

You can check your running nginx instance by going to `http://yourdomain` in your browser.

To set up the reverse proxy for redirecting requests to the gunicorn socket replace the default config with this:

```nginx
server {
        listen 80 default_server;
        listen [::]:80 default_server;

        server_name yourdomain;

        location / {
                include proxy_params;
                proxy_pass http://unix:/home/3digi/digital_3g/backend/digital_3g.sock;
        }
}
```

To wrap up things, nginx has to be reloaded by executing 

```bash
systemctl force-reload nginx.service
```

The API should be running now.

## Misc 

Fot authentication a working SSL configuration for the HTTP server is required. A guide for setup of a free SSL certificate with nginx can be found here https://www.nginx.com/blog/using-free-ssltls-certificates-from-lets-encrypt-with-nginx/

If you would rather use uWSGI for running the server in production, you can find a nice guide here https://www.digitalocean.com/community/tutorials/how-to-serve-flask-applications-with-uswgi-and-nginx-on-ubuntu-18-04

For further documentation on running Flask applications see https://flask.palletsprojects.com/en/2.0.x/
