class ColorAllocation {
  final int? id;
  final DateTime day;
  final int colorId;
  final int colorHex;
  final bool colorInverse;
  final String? colorName;

  ColorAllocation({
    this.id,
    required this.day,
    required this.colorId,
    required this.colorHex,
    this.colorName,
    this.colorInverse = false,
  });

  factory ColorAllocation.fromMap(Map map) => ColorAllocation(
        id: map['id'] as int,
        day: DateTime.parse(map['day'] as String),
        colorId: map['color_id'] as int,
        colorHex: int.parse(map['color_hex'] as String, radix: 16),
        colorName: map['color_hex'] as String,
        colorInverse: map['color_inverse'] != null ? map['color_inverse'] as bool : false,
      );

  Map<String, dynamic> get toMap => {
        'id': id,
        'day': day.toIso8601String().split('T').first,
        'color_id': colorId,
      };

  Map<String, dynamic> get toMapLong => {
        ...toMap,
        'color_name': colorName,
        'color_hex': colorHex,
        'color_inverse': colorInverse,
      };

  ColorAllocation copyWith({
    int? id,
    DateTime? day,
    int? colorId,
    int? colorHex,
    bool? colorInverse,
  }) {
    return ColorAllocation(
      id: id ?? this.id,
      day: day ?? this.day,
      colorId: colorId ?? this.colorId,
      colorHex: colorHex ?? this.colorHex,
      colorInverse: colorInverse ?? this.colorInverse,
    );
  }

  @override
  String toString() => '[ColorAllocation $toMapLong]';
}
