import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_phoenix/flutter_phoenix.dart';
import 'package:path_provider/path_provider.dart';
import 'package:provider/provider.dart';

import '../api/auth_api.dart';
import '../widgets/admin_view.dart';
import '../widgets/auth_guard.dart';
import '../widgets/user_view.dart';

class HomePage extends StatefulWidget {
  final bool isAdmin;

  const HomePage({key, required this.isAdmin}) : super(key: key);

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Image.asset(
          'assets/uni_logo.png',
          package: 'digital_3g_common',
          height: 40.0,
        ),
        actions: [
          IconButton(
            onPressed: () => Navigator.of(context).pushNamed('/settings'),
            icon: const Icon(Icons.settings),
            tooltip: 'Einstellungen',
          ),
          IconButton(
            onPressed: _onLogout,
            icon: const Icon(Icons.logout_rounded),
            tooltip: 'Ausloggen',
          ),
        ],
      ),
      body: AuthGuard(child: widget.isAdmin ? const AdminView() : const UserView()),
    );
  }

  void _onLogout() async {
    await Provider.of<AuthApi>(context, listen: false).logout();

    // delete pubkey from filesystem
    final basePath = (await getApplicationDocumentsDirectory()).path;
    final keyFile = File('$basePath/public_key.pem');
    if (keyFile.existsSync()) {
      await File('$basePath/public_key.pem').delete();
    }

    final credentials = File('$basePath/credentials');
    if (credentials.existsSync()) {
      await credentials.delete();
    }

    Phoenix.rebirth(context);
  }
}
