import 'package:digital_3g_common/backend_switcher.dart';
import 'package:digital_3g_common/ui.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:provider/provider.dart';

import '../api/admin_api.dart';
import '../api/auth_api.dart';
import '../models/ribbon_color.dart';

class AdminView extends StatefulWidget {
  const AdminView({Key? key}) : super(key: key);

  @override
  _AdminViewState createState() => _AdminViewState();
}

class _AdminViewState extends State<AdminView> {
  RibbonColor _currentColor = RibbonColor(hex: Colors.grey.value);
  AdminApi? _adminApi;

  @override
  Widget build(BuildContext context) {
    return RefreshIndicator(
      onRefresh: _onUpdateColor,
      child: Center(
        child: ConstrainedBox(
          constraints: const BoxConstraints(maxWidth: 640.0),
          child: GridView.count(
            crossAxisCount: 1,
            childAspectRatio: 5 / 4,
            padding: const EdgeInsets.all(8.0),
            children: [
              PaddedCard(
                margin: null,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    Text('Heutige Bändchenfarbe', style: Theme.of(context).textTheme.headline5),
                    Center(
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: ColorCircle(
                          color: Color(_currentColor.hex),
                          onTap: _onUpdateColor,
                          borderSide: BorderSide.none,
                          radius: MediaQuery.of(context).size.width >= 768.0
                              ? 196.0
                              : MediaQuery.of(context).size.width / 3.5,
                          padding: const EdgeInsets.all(32.0),
                          inverse: _currentColor.inverse,
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              GridView.count(
                crossAxisCount: 2,
                childAspectRatio: 5 / 4,
                shrinkWrap: true,
                physics: const NeverScrollableScrollPhysics(),
                children: [
                  Card(
                    child: InkWell(
                      onTap: () async {
                        await Navigator.of(context).pushNamed('/admin/color_allocations');
                        _onUpdateColor();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Stack(
                          alignment: Alignment.topLeft,
                          children: [
                            Text('Farbzuweisung', style: Theme.of(context).textTheme.headline6),
                            const Center(child: Icon(Icons.calendar_today_rounded, size: 64.0)),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Card(
                    child: InkWell(
                      onTap: () async {
                        await Navigator.of(context).pushNamed('/admin/colors');
                        _onUpdateColor();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Stack(
                          alignment: Alignment.topLeft,
                          children: [
                            Text('Farben', style: Theme.of(context).textTheme.headline6),
                            const Center(child: Icon(Icons.color_lens_rounded, size: 64.0)),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Card(
                    child: InkWell(
                      onTap: () => Navigator.of(context).pushNamed('/admin/users'),
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Stack(
                          alignment: Alignment.topLeft,
                          children: [
                            Text('Nutzer', style: Theme.of(context).textTheme.headline6),
                            const Center(child: Icon(Icons.manage_accounts_rounded, size: 64.0)),
                          ],
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  @override
  void didChangeDependencies() async {
    final _client = Provider.of<AuthApi>(context, listen: false).client;
    _adminApi = AdminApi(_client, BlocProvider.of<BackendSwitcher>(context).state);

    _onUpdateColor();
    super.didChangeDependencies();
  }

  Future<void> _onUpdateColor() async {
    final value = await _adminApi!.getCurrentColor();
    if (value != null) {
      setState(() {
        _currentColor = RibbonColor(hex: value.colorHex, inverse: value.colorInverse);
      });
    }
  }
}
